/*
       consts.h
       GNU Licence

       author: Rafal Michniewicz 
        email: <rafim@data.pl>
       jabber: rafim@jabber.airm.net
    home page: http://smbc.airm.net
  
    last update: 2004-03-01
*/

#define RMAXGHLEN 255
#define RMAXPATHTOSMBCLIENT 1024
#define RMESSAGEDIR "/tmp/smbc"
#define RMESSAGEFILE "smbc_message"
#define RWINPOPUPMAXLEN 160

